@@ -15,8 +15,10 @@
 
 import threading
 import time
+from unittest import mock
 
-import mock
+from oslo_config import fixture as config
+from oslo_serialization import jsonutils
 from oslotest import base as test_base
 import requests
 import webob.dec
@@ -50,6 +52,10 @@ class HealthcheckMainTests(test_base.BaseTestCase):
 
 class HealthcheckTests(test_base.BaseTestCase):
 
+    def setUp(self):
+        super(HealthcheckTests, self).setUp()
+        self.useFixture(config.Config())
+
     @staticmethod
     @webob.dec.wsgify
     def application(req):
@@ -187,3 +193,10 @@ class HealthcheckTests(test_base.BaseTestCase):
                       expected_body=b'DISABLED BY FILE',
                       server_port=81)
         self.assertIn('disable_by_files_ports', self.app._backends.names())
+
+    def test_json_response(self):
+        expected_body = jsonutils.dumps({'detailed': False, 'reasons': []},
+                                        indent=4,
+                                        sort_keys=True).encode('utf-8')
+        self._do_test(expected_body=expected_body,
+                      accept='application/json')
