@@ -31,8 +31,7 @@ class TestHTTPProxyToWSGI(test_base.BaseTestCase):
         self.middleware = http_proxy_to_wsgi.HTTPProxyToWSGI(fake_app)
         self.middleware.oslo_conf.set_override('enable_proxy_headers_parsing',
                                                True,
-                                               group='oslo_middleware',
-                                               enforce_type=True)
+                                               group='oslo_middleware')
         self.request = webob.Request.blank('/foo/bar', method='POST')
 
     def test_backward_compat(self):
@@ -40,8 +39,7 @@ class TestHTTPProxyToWSGI(test_base.BaseTestCase):
         def fake_app(req):
             return util.application_uri(req.environ)
 
-        self.middleware = http_proxy_to_wsgi.HTTPProxyToWSGIMiddleware(
-            fake_app)
+        self.middleware = http_proxy_to_wsgi.HTTPProxyToWSGI(fake_app)
         response = self.request.get_response(self.middleware)
         self.assertEqual(b"http://localhost:80/", response.body)
 
@@ -90,6 +88,18 @@ class TestHTTPProxyToWSGI(test_base.BaseTestCase):
         response = self.request.get_response(self.middleware)
         self.assertEqual(b"https://localhost:80/", response.body)
 
+    def test__parse_rfc7239_header(self):
+        expected_result = [{'for': 'foobar', 'proto': 'https'},
+                           {'for': 'foobaz', 'proto': 'http'}]
+
+        result = self.middleware._parse_rfc7239_header(
+            "for=foobar;proto=https, for=foobaz;proto=http")
+        self.assertEqual(expected_result, result)
+
+        result = self.middleware._parse_rfc7239_header(
+            "for=foobar; proto=https, for=foobaz; proto=http")
+        self.assertEqual(expected_result, result)
+
     def test_rfc7239_proto_host(self):
         self.request.headers['Forwarded'] = (
             "for=foobar;proto=https;host=example.com, for=foobaz;proto=http")
@@ -103,6 +113,28 @@ class TestHTTPProxyToWSGI(test_base.BaseTestCase):
         response = self.request.get_response(self.middleware)
         self.assertEqual(b"https://example.com:8043/bla", response.body)
 
+    def test_forwarded_for_headers(self):
+        @webob.dec.wsgify()
+        def fake_app(req):
+            return req.environ['REMOTE_ADDR']
+
+        self.middleware = http_proxy_to_wsgi.HTTPProxyToWSGI(fake_app)
+        forwarded_for_addr = '1.2.3.4'
+        forwarded_addr = '8.8.8.8'
+
+        # If both X-Forwarded-For and Fowarded headers are present, it should
+        # use the Forwarded header and ignore the X-Forwarded-For header.
+        self.request.headers['Forwarded'] = (
+            "for=%s;proto=https;host=example.com:8043" % (forwarded_addr))
+        self.request.headers['X-Forwarded-For'] = forwarded_for_addr
+        response = self.request.get_response(self.middleware)
+        self.assertEqual(forwarded_addr.encode(), response.body)
+
+        # Now if only X-Forwarded-For header is present, it should be used.
+        del self.request.headers['Forwarded']
+        response = self.request.get_response(self.middleware)
+        self.assertEqual(forwarded_for_addr.encode(), response.body)
+
 
 class TestHTTPProxyToWSGIDisabled(test_base.BaseTestCase):
 
@@ -116,8 +148,7 @@ class TestHTTPProxyToWSGIDisabled(test_base.BaseTestCase):
         self.middleware = http_proxy_to_wsgi.HTTPProxyToWSGI(fake_app)
         self.middleware.oslo_conf.set_override('enable_proxy_headers_parsing',
                                                False,
-                                               group='oslo_middleware',
-                                               enforce_type=True)
+                                               group='oslo_middleware')
         self.request = webob.Request.blank('/foo/bar', method='POST')
 
     def test_no_headers(self):
